summaryrefslogtreecommitdiff
path: root/framework/Web/UI/WebControls
diff options
context:
space:
mode:
authorxue <>2006-04-20 17:06:59 +0000
committerxue <>2006-04-20 17:06:59 +0000
commit5d02ac2219c95459afb8f7dc7a0457b5c0e98fd0 (patch)
tree7fc6cb52a921bcad0cafc61d35c2e9cf675bbe61 /framework/Web/UI/WebControls
parentf4a715e98befac72626b7d7a94f98882fee37c32 (diff)
Fixed #138 and an error in HTML entity representation for double quotes.
Diffstat (limited to 'framework/Web/UI/WebControls')
-rw-r--r--framework/Web/UI/WebControls/THtmlArea.php9
-rw-r--r--framework/Web/UI/WebControls/TTableRow.php3
2 files changed, 10 insertions, 2 deletions
diff --git a/framework/Web/UI/WebControls/THtmlArea.php b/framework/Web/UI/WebControls/THtmlArea.php
index 7ad2d06f..038c7368 100644
--- a/framework/Web/UI/WebControls/THtmlArea.php
+++ b/framework/Web/UI/WebControls/THtmlArea.php
@@ -11,6 +11,11 @@
*/
/**
+ * Includes TTextBox class
+ */
+Prado::using('System.Web.UI.WebControls.TTextBox');
+
+/**
* THtmlArea class
*
* THtmlArea wraps the visual editting functionalities provided by the
@@ -73,7 +78,8 @@
*/
class THtmlArea extends TTextBox
{
- protected $langs = array(
+ // Qiang: need to clean up the following (too inefficient)
+ private $langs = array(
'da' => array('da'),
'fa' => array('fa'),
'hu' => array('hu'),
@@ -310,6 +316,7 @@ class THtmlArea extends TTextBox
if(count($variants) == 0)
$variants[] = empty($culture) ? 'en' : strtolower($culture);
+ // TODO: triple loops???
foreach($this->langs as $js => $langs)
{
foreach($variants as $variant)
diff --git a/framework/Web/UI/WebControls/TTableRow.php b/framework/Web/UI/WebControls/TTableRow.php
index 04a1555d..6a3f196a 100644
--- a/framework/Web/UI/WebControls/TTableRow.php
+++ b/framework/Web/UI/WebControls/TTableRow.php
@@ -11,9 +11,10 @@
*/
/**
* Includes TTableCell class
*/
Prado::using('System.Web.UI.WebControls.TTableCell');
+Prado::using('System.Web.UI.WebControls.TTableHeaderCell');
/**
* TTableRow class.
@@ -11,9 +11,10 @@
*/
/**
- * Includes TTableCell class
+ * Includes TTableCell and TTableHeaderCell classes
*/
Prado::using('System.Web.UI.WebControls.TTableCell');